@@ -1,12 +1,11 @@
-use crate::ast;
-use crate::{Parse, Spanned, ToTokens};
+use crate::ast::prelude::*;
 
 /// A block expression.
 ///
 /// # Examples
 ///
-/// ```rust
-/// use rune::{testing, ast};
+/// ```
+/// use rune::{ast, testing};
 ///
 /// let expr = testing::roundtrip::<ast::ExprBlock>("async {}");
 /// assert_eq!(expr.block.statements.len(), 0);
@@ -20,6 +19,7 @@ use crate::{Parse, Spanned, ToTokens};
 /// ```
 #[derive(Debug, Clone, PartialEq, Eq, Parse, ToTokens, Spanned)]
 #[rune(parse = "meta_only")]
+#[non_exhaustive]
 pub struct ExprBlock {
     /// The attributes for the block.
     #[rune(iter, meta)]
