@@ -1,10 +1,9 @@
-use crate::ast;
-use crate::{Parse, ParseError, Parser, Peek, Peeker, Spanned, ToTokens};
+use crate::ast::prelude::*;
 
 /// A `break` statement: `break [expr]`.
 ///
-/// ```rust
-/// use rune::{testing, ast};
+/// ```
+/// use rune::{ast, testing};
 ///
 /// testing::roundtrip::<ast::ExprBreak>("break");
 /// testing::roundtrip::<ast::ExprBreak>("break 42");
@@ -12,6 +11,7 @@ use crate::{Parse, ParseError, Parser, Peek, Peeker, Spanned, ToTokens};
 /// ```
 #[derive(Debug, Clone, PartialEq, Eq, Parse, ToTokens, Spanned)]
 #[rune(parse = "meta_only")]
+#[non_exhaustive]
 pub struct ExprBreak {
     /// The attributes of the `break` expression
     #[rune(iter, meta)]
@@ -20,13 +20,14 @@ pub struct ExprBreak {
     pub break_token: T![break],
     /// An optional expression to break with.
     #[rune(iter)]
-    pub expr: Option<ExprBreakValue>,
+    pub expr: Option<Box<ExprBreakValue>>,
 }
 
 expr_parse!(Break, ExprBreak, "break expression");
 
 /// Things that we can break on.
 #[derive(Debug, Clone, PartialEq, Eq, ToTokens, Spanned)]
+#[non_exhaustive]
 pub enum ExprBreakValue {
     /// Breaking a value out of a loop.
     Expr(ast::Expr),
