@@ -1,12 +1,11 @@
-use crate::ast;
-use crate::{Parse, Spanned, ToTokens};
+use crate::ast::prelude::*;
 
 /// A `loop` expression: `loop { ... }`.
 ///
 /// # Examples
 ///
-/// ```rust
-/// use rune::{testing, ast};
+/// ```
+/// use rune::{ast, testing};
 ///
 /// testing::roundtrip::<ast::ExprLoop>("loop {}");
 /// testing::roundtrip::<ast::ExprLoop>("loop { 1; }");
@@ -15,6 +14,7 @@ use crate::{Parse, Spanned, ToTokens};
 /// ```
 #[derive(Debug, Clone, PartialEq, Eq, Parse, ToTokens, Spanned)]
 #[rune(parse = "meta_only")]
+#[non_exhaustive]
 pub struct ExprLoop {
     /// The attributes for the `loop`
     #[rune(iter, meta)]
