@@ -1,18 +1,18 @@
-use crate::ast;
-use crate::{Parse, ParseError, Parser, Spanned, ToTokens};
+use crate::ast::prelude::*;
 
 /// A single argument in a closure.
 ///
 /// # Examples
 ///
-/// ```rust
-/// use rune::{testing, ast};
+/// ```
+/// use rune::{ast, testing};
 ///
 /// testing::roundtrip::<ast::FnArg>("self");
 /// testing::roundtrip::<ast::FnArg>("_");
 /// testing::roundtrip::<ast::FnArg>("abc");
 /// ```
 #[derive(Debug, Clone, PartialEq, Eq, ToTokens, Spanned)]
+#[non_exhaustive]
 pub enum FnArg {
     /// The `self` parameter.
     SelfValue(T![self]),
